@@ -28,6 +28,7 @@ along with Flexo.  If not, see <http://www.gnu.org/licenses/>.
 class QTimer;
 class QUndoStack;
 class QActionGroup;
+class QFile;
 class Alarm;
 class BalanceWindow;
 class ExitDialog;
@@ -52,6 +53,7 @@ public slots:
     void Activate();
     void setAlarm();
     void removeAlarm();
+    void setInactive(bool);
 
 private slots:
 
@@ -60,15 +62,14 @@ private slots:
     void on_settingsButton_clicked();
 
     void updateTime();
-
     void toggleAlarm(bool);
-
     void reset();
-
     void onTimer();
 
 protected:
-    void closeEvent(QCloseEvent *event);
+    void closeEvent(QCloseEvent*);
+
+    bool event (QEvent*);
 
 private:
 
@@ -82,6 +83,8 @@ private:
     void displayBalance();
     void createUndoActions();
     void showWarning(const QString&);
+    QString timeText(const QDateTime&);
+    void restoreLegacyData(QFile&);
 
     Alarm* createAlarm();
 
